searchData={"items":[{"type":"module","title":"Argon2","doc":"Elixir wrapper for the Argon2 password hashing function.\n\nFor a lower-level API, see `Argon2.Base`.","ref":"Argon2.html"},{"type":"module","title":"Configuration - Argon2","doc":"See the documentation for `Argon2.Stats` for information about configuration.","ref":"Argon2.html#module-configuration"},{"type":"module","title":"Argon2 - Argon2","doc":"Argon2 is the winner of the [Password Hashing Competition (PHC)](https://password-hashing.net).\n\nArgon2 is a memory-hard password hashing function which can be used to hash\npasswords for credential storage, key derivation, or other applications.\n\nArgon2 has the following three variants (Argon2id is the default):\n\n  * Argon2d - suitable for applications with no threats from side-channel\n  timing attacks (eg. cryptocurrencies)\n  * Argon2i - suitable for password hashing and password-based key derivation\n  * Argon2id - a hybrid of Argon2d and Argon2i\n\nArgon2i, Argon2d, and Argon2id are parametrized by:\n\n  * A **time** cost, which defines the amount of computation realized and\n  therefore the execution time, given in number of iterations\n  * A **memory** cost, which defines the memory usage, given in kibibytes\n  * A **parallelism** degree, which defines the number of parallel threads\n\nMore information can be found in the documentation for the `Argon2.Stats`\nmodule and at the [Argon2 reference C implementation\nrepository](https://github.com/P-H-C/phc-winner-argon2).","ref":"Argon2.html#module-argon2"},{"type":"module","title":"Comparison with Bcrypt / Pbkdf2 - Argon2","doc":"Argon2 has better password cracking resistance than Bcrypt and Pbkdf2.\nIts main advantage is that, as it is a memory-hard function, it is designed\nto withstand parallel attacks that use GPUs or other dedicated hardware.","ref":"Argon2.html#module-comparison-with-bcrypt-pbkdf2"},{"type":"function","title":"Argon2.hash_pwd_salt/2","doc":"Hashes a password with a randomly generated salt.","ref":"Argon2.html#hash_pwd_salt/2"},{"type":"function","title":"Options - Argon2.hash_pwd_salt/2","doc":"In addition to the `:salt_len` option shown below, this function also takes\noptions that are then passed on to the `hash_password` function in the\n`Argon2.Base` module.\n\nSee the documentation for `Argon2.Base.hash_password/3` for further details.\n\n  * `:salt_len` - the length of the random salt\n    * the default is 16 (the minimum is 8) bytes","ref":"Argon2.html#hash_pwd_salt/2-options"},{"type":"function","title":"Examples - Argon2.hash_pwd_salt/2","doc":"The following examples show how to hash a password with a randomly-generated\nsalt and then verify a password:\n\n    iex> hash = Argon2.hash_pwd_salt(\"password\")\n    ...> Argon2.verify_pass(\"password\", hash)\n    true\n\n    iex> hash = Argon2.hash_pwd_salt(\"password\")\n    ...> Argon2.verify_pass(\"incorrect\", hash)\n    false","ref":"Argon2.html#hash_pwd_salt/2-examples"},{"type":"function","title":"Argon2.no_user_verify/1","doc":"Runs the password hash function, but always returns false.\n\nThis function is intended to make it more difficult for any potential\nattacker to find valid usernames by using timing attacks. This function\nis only useful if it is used as part of a policy of hiding usernames.","ref":"Argon2.html#no_user_verify/1"},{"type":"function","title":"Options - Argon2.no_user_verify/1","doc":"This function should be called with the same options as those used by\n`hash_pwd_salt/2`.","ref":"Argon2.html#no_user_verify/1-options"},{"type":"function","title":"Hiding usernames - Argon2.no_user_verify/1","doc":"In addition to keeping passwords secret, hiding the precise username\ncan help make online attacks more difficult. An attacker would then\nhave to guess a username / password combination, rather than just\na password, to gain access.\n\nThis does not mean that the username should be kept completely secret.\nAdding a short numerical suffix to a user's name, for example, would be\nsufficient to increase the attacker's work considerably.\n\nIf you are implementing a policy of hiding usernames, it is important\nto make sure that the username is not revealed by any other part of\nyour application.","ref":"Argon2.html#no_user_verify/1-hiding-usernames"},{"type":"function","title":"Argon2.verify_pass/2","doc":"Verifies a password by hashing the password and comparing the hashed value\nwith a stored hash.\n\nSee the documentation for `hash_pwd_salt/2` for examples of using this function.","ref":"Argon2.html#verify_pass/2"},{"type":"module","title":"Argon2.Base","doc":"Lower-level api for Argon2.\n\nThese functions can be useful if you want more control over some\nof the options. In most cases, you will not need to call these\nfunctions directly.","ref":"Argon2.Base.html"},{"type":"function","title":"Argon2.Base.encodedlen_nif/6","doc":"Calculate the length of the encoded hash.","ref":"Argon2.Base.html#encodedlen_nif/6"},{"type":"function","title":"Argon2.Base.error_nif/1","doc":"Translate the error code to an error message.","ref":"Argon2.Base.html#error_nif/1"},{"type":"function","title":"Argon2.Base.gen_salt/1","doc":"Generate a random salt.\n\nThe default length for the salt is 16 bytes. We do not recommend using\na salt shorter than the default.","ref":"Argon2.Base.html#gen_salt/1"},{"type":"function","title":"Argon2.Base.handle_error/1","doc":"","ref":"Argon2.Base.html#handle_error/1"},{"type":"function","title":"Argon2.Base.hash_nif/10","doc":"Hash a password using Argon2.","ref":"Argon2.Base.html#hash_nif/10"},{"type":"function","title":"Argon2.Base.hash_password/3","doc":"Hash a password using Argon2.","ref":"Argon2.Base.html#hash_password/3"},{"type":"function","title":"Options - Argon2.Base.hash_password/3","doc":"There are six options:\n\n  * `:t_cost` - time cost\n    * the default is 3\n  * `:m_cost` - memory usage\n    * the default is 16 - this will produce a memory usage of 64 MiB (2 ^ 16 KiB)\n  * `:parallelism` - number of parallel threads\n    * the default is 4\n  * `:format` - output format\n    * this value can be\n      * `:encoded` - encoded with Argon2 crypt format\n      * `:raw_hash` - raw hash output in hexadecimal format\n      * `:report` - raw hash and encoded hash, together with the options used\n    * `:encoded` is the default\n  * `:hashlen` - length of the hash (in bytes)\n    * the default is 32\n  * `:argon2_type` - Argon2 type\n    * this value should be 0 (Argon2d), 1 (Argon2i) or 2 (Argon2id)\n    * the default is 2 (Argon2id)\n\nThe `t_cost`, `m_cost`, `parallelism` and `argon2_type` can also be\nset in the config. See the documentation for Argon2.Stats for more\ninformation about choosing these values.","ref":"Argon2.Base.html#hash_password/3-options"},{"type":"function","title":"Examples - Argon2.Base.hash_password/3","doc":"The following example changes the default `t_cost` and `m_cost`:\n\n    Argon2.Base.hash_password(\"password\", \"somesaltSOMESALT\", [t_cost: 4, m_cost: 18])\n\nIn the example below, the Argon2 type is changed to Argon2d:\n\n    Argon2.Base.hash_password(\"password\", \"somesaltSOMESALT\", [argon2_type: 0])\n\nTo use Argon2i, use `argon2_type: 1`.","ref":"Argon2.Base.html#hash_password/3-examples"},{"type":"function","title":"Argon2.Base.init/0","doc":"","ref":"Argon2.Base.html#init/0"},{"type":"function","title":"Argon2.Base.verify_nif/3","doc":"Verify a password using Argon2.","ref":"Argon2.Base.html#verify_nif/3"},{"type":"module","title":"Argon2.Stats","doc":"Module to provide statistics for the Argon2 password hashing function.\n\nThe `report/1` function in this module can be used to help you configure\nArgon2.","ref":"Argon2.Stats.html"},{"type":"module","title":"Configuration - Argon2.Stats","doc":"The following four parameters can be set in the config file\n(these can all be overridden using keyword options):\n\n  * t_cost - time cost\n    * the amount of computation, given in number of iterations\n    * 3 is the default\n  * m_cost - memory usage\n    * 16 is the default - this will produce a memory usage of 64 MiB (2 ^ 16 KiB)\n  * parallelism - number of parallel threads\n    * 4 is the default\n  * argon2_type - argon2 variant to use\n    * 0 (Argon2d), 1 (Argon2i) or 2 (Argon2id)\n    * 2 is the default (Argon2id)\n\nIt is important to note that the default values are not necessarily\nthe recommended values. A lot will depend on what hardware you are\nusing and how much time you want the hashing function to take. See\nthe Choosing parameters section for more details.\n\n#","ref":"Argon2.Stats.html#module-configuration"},{"type":"module","title":"Test values - Argon2.Stats","doc":"The following values can be used to speed up tests.\n\n    config :argon2_elixir,\n      t_cost: 1,\n      m_cost: 8\n\nNB. do not use these values in production.","ref":"Argon2.Stats.html#module-test-values"},{"type":"module","title":"Choosing parameters - Argon2.Stats","doc":"The following is a guide on how to choose the parameters.\n\n  1. Decide which type to use. If you do not know the difference between\n  the types, choose Argon2id.\n  2. Decide how many threads to use - the parallelism option.\n  3. Decide how much memory each call should use - m_cost.\n  4. Decide how much time each call should take.\n    a. The Argon2 draft guidelines recommend 500 milliseconds (0.5 seconds).\n  5. Run the function using the values chosen in steps 1-3. Work out\n  the maximum t_cost (number of iterations) such that the running time\n  does not exceed the value chosen in step 4. If the time taken exceeds\n  the value chosen in step 4 even for one iteration, reduce the m_cost\n  accordingly.","ref":"Argon2.Stats.html#module-choosing-parameters"},{"type":"function","title":"Argon2.Stats.report/1","doc":"Hash a password with Argon2 and print out a report.\n\nThis function hashes the password and salt with `Argon2.Base.hash_password/3`\nand prints out statistics which can help you choose how to configure Argon2.","ref":"Argon2.Stats.html#report/1"},{"type":"function","title":"Options - Argon2.Stats.report/1","doc":"In addition to the options for `Argon2.Base.hash_password/3`, there are\nalso the following options:\n\n  * `:password` - the password used\n    * the default is \"password\"\n  * `:salt` - the salt used\n    * the default is \"somesaltSOMESALT\"","ref":"Argon2.Stats.html#report/1-options"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"v4.0.0 (2023-10-07) - Changelog","doc":"* Enhancements\n  * updated default configuration values in line with RFC9106","ref":"changelog.html#v4-0-0-2023-10-07"},{"type":"extras","title":"v3.2.0 (2023-08-26) - Changelog","doc":"* Bug fixes\n  * fixed Windows build for Erlang 26","ref":"changelog.html#v3-2-0-2023-08-26"},{"type":"extras","title":"v3.1.0 (2021-03-23) - Changelog","doc":"* Enhancements\n  * added support for building on SunOS (Illumos / Solaris)\n\n* Changes\n  * updated documentation and README\n  * updated dialyxir dependency","ref":"changelog.html#v3-1-0-2021-03-23"},{"type":"extras","title":"v3.0.0 (2021-01-20) - Changelog","doc":"* Enhancements\n  * updated default memory cost and parallelism values\n    * memory cost (m_cost) is now 16 (64 MiB) and parallelism is now 2\n* Changes\n  * moved `gen_salt` to the `Base` module","ref":"changelog.html#v3-0-0-2021-01-20"},{"type":"extras","title":"v2.4.1 (2021-01-19) - Changelog","doc":"* Changes\n  * updated documentation and README","ref":"changelog.html#v2-4-1-2021-01-19"},{"type":"extras","title":"v2.4.0 (2021-01-09) - Changelog","doc":"* Enhancements\n  * updated Makefile to be more robust, especially for Nerves users","ref":"changelog.html#v2-4-0-2021-01-09"},{"type":"extras","title":"v2.3.0 (2020-03-01) - Changelog","doc":"* Changes\n  * using Comeonin v5.3, which changes `add_hash` so that it does NOT set the password to nil","ref":"changelog.html#v2-3-0-2020-03-01"},{"type":"extras","title":"v2.2.0 (2020-01-15) - Changelog","doc":"* Enhancements\n  * Updated documentation - in line with updates to Comeonin v5.2","ref":"changelog.html#v2-2-0-2020-01-15"},{"type":"extras","title":"v2.0.0 (2019-02-12) - Changelog","doc":"* Enhancements\n  * Updated to use the Comeonin and Comeonin.PasswordHash behaviours (Comeonin v5.0)\n  * Made Argon2id the default Argon2 type\n  * Changed default t_cost, m_cost and parallelism values","ref":"changelog.html#v2-0-0-2019-02-12"},{"type":"extras","title":"v1.3.1 (2018-06-28) - Changelog","doc":"* Bug fixes\n  * Added :erlang.nif_error for use with NIFs","ref":"changelog.html#v1-3-1-2018-06-28"},{"type":"extras","title":"v1.3 (2018-05-13) - Changelog","doc":"* Bug fixes\n  * Fixed bug that was raising errors when used in releases","ref":"changelog.html#v1-3-2018-05-13"},{"type":"extras","title":"v1.2.4 (2018-12-09) - Changelog","doc":"* Enhancements\n  * Improved Windows support by removing VLAs from nif code","ref":"changelog.html#v1-2-4-2018-12-09"},{"type":"extras","title":"v1.2.0 (2017-07-14) - Changelog","doc":"* Changes\n  * Removed the `opts` argument to `verify_pass` - it is now `verify_pass/2`\n  * Deprecated `verify_hash` - this will be removed in version 2","ref":"changelog.html#v1-2-0-2017-07-14"},{"type":"extras","title":"v1.1.0 (2017-07-12) - Changelog","doc":"* Changes\n  * Added a `verify_pass` function - this is to be more in line with other libraries' verify functions","ref":"changelog.html#v1-1-0-2017-07-12"},{"type":"extras","title":"v1.0.0 (2017-07-06) - Changelog","doc":"* Changes\n  * Updates to the documentation","ref":"changelog.html#v1-0-0-2017-07-06"},{"type":"extras","title":"v0.12.0 (2017-01-16) - Changelog","doc":"* Enhancements\n  * Added `no_user_verify` dummy verify function to help prevent username enumeration","ref":"changelog.html#v0-12-0-2017-01-16"},{"type":"extras","title":"v0.11.0 (2016-11-09) - Changelog","doc":"* Enhancements\n  * Made t_cost, m_cost and parallelism configurable with the config file\n    * This makes it easier to set different values for tests","ref":"changelog.html#v0-11-0-2016-11-09"},{"type":"extras","title":"v0.10.0 (2016-11-06) - Changelog","doc":"* Enhancements\n  * Added report function\n    * This provides an output similar to the reference command line app\n* Changes\n  * Changed raw_output and encoded_output options - now there is a single format option","ref":"changelog.html#v0-10-0-2016-11-06"},{"type":"extras","title":"v0.9.0 (2016-10-28) - Changelog","doc":"* Bug fixes\n  * Fixed hex package","ref":"changelog.html#v0-9-0-2016-10-28"},{"type":"extras","title":"License","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# Argon2\n\n[![Build Status](https://travis-ci.com/riverrun/argon2_elixir.svg?branch=master)](https://travis-ci.com/riverrun/argon2_elixir)\n[![Hex Version](https://img.shields.io/hexpm/v/argon2_elixir.svg)](https://hex.pm/packages/argon2_elixir)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/argon2_elixir/)\n[![Total Download](https://img.shields.io/hexpm/dt/argon2_elixir.svg)](https://hex.pm/packages/argon2_elixir)\n[![License](https://img.shields.io/hexpm/l/argon2_elixir.svg)](https://github.com/riverrun/argon2_elixir/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/riverrun/argon2_elixir.svg)](https://github.com/riverrun/argon2_elixir/commits/master)\n\n\nArgon2 password hashing library for Elixir.\n\n[Argon2](https://github.com/P-H-C/phc-winner-argon2) is the official winner\nof the [Password Hashing Competition](https://password-hashing.net/),\na several year project to identify a successor to Bcrypt / Pbkdf2 / Scrypt\npassword hashing methods.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"1.  Add `:argon2_elixir` to your list of dependencies in `mix.exs`:\n\n    ```elixir\n    def deps do\n      [\n        {:argon2_elixir, \"~> 4.0\"}\n      ]\n    end\n    ```\n\n2.  Optional: during tests (and tests only), you may want to speed up the tests. If you have a `config/test.exs`, you can add:\n\n    ```elixir\n    config :argon2_elixir,\n      t_cost: 1,\n      m_cost: 8\n    ```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Overview","doc":"Configure `argon2_elixir` - see the documentation for\n[`Argon2.Stats`](https://hexdocs.pm/argon2_elixir/Argon2.Stats.html) for more details","ref":"readme.html#configuration"},{"type":"extras","title":"Comeonin wiki - Overview","doc":"See the [Comeonin wiki](https://github.com/riverrun/comeonin/wiki) for more\ninformation on the following topics:\n\n* [algorithms](https://github.com/riverrun/comeonin/wiki/Choosing-the-password-hashing-algorithm)\n* [requirements](https://github.com/riverrun/comeonin/wiki/Requirements)\n* [deployment](https://github.com/riverrun/comeonin/wiki/Deployment)\n  * including information about using Docker\n* [references](https://github.com/riverrun/comeonin/wiki/References)","ref":"readme.html#comeonin-wiki"},{"type":"extras","title":"Contributing - Overview","doc":"There are many ways you can contribute to the development of this library, including:\n\n* reporting issues\n* improving documentation\n* sharing your experiences with others\n\n#","ref":"readme.html#contributing"},{"type":"extras","title":"Development - Overview","doc":"```bash\n$ git clone https://github.com/riverrun/argon2_elixir\n$ git submodule update --init --recursive\n$ mix do deps.get, compile\n$ mix test\n```\n\n#","ref":"readme.html#development"},{"type":"extras","title":"Documentation - Overview","doc":"http://hexdocs.pm/argon2_elixir","ref":"readme.html#documentation"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2016 David Whitlock\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [https://www.apache.org/licenses/LICENSE-2.0](https://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown"}